@@ -1,24 +1,25 @@
-from importlib import import_module
 import warnings
 
+from pyot.conf.utils import import_confs
+from pyot.core.warnings import PyotConfWarning
+
+
 try:
     from django.core.exceptions import ImproperlyConfigured
     try:
         from django.conf import settings
 
-        try:
-            paths = settings.PYOT_CONFS
-        except AttributeError:
-            paths = settings.PYOT_SETTINGS
-            warnings.warn("'PYOT_SETTINGS' is deprecated in favor of 'PYOT_CONFS'", DeprecationWarning)
+        conf_paths = settings.PYOT_CONFS
         DJANGO_ENABLED = True
     except ImproperlyConfigured:
         DJANGO_ENABLED = False
+    except AttributeError:
+        warnings.warn("Django install detected, but could not find `PYOT_CONFS` settings variable", PyotConfWarning)
+        DJANGO_ENABLED = False
 except (ImportError, ModuleNotFoundError, NameError):
     DJANGO_ENABLED = False
 
 
 def activate():
     if DJANGO_ENABLED:
-        for path in paths:
-            import_module(path)
+        import_confs(conf_paths)
